@@ -7,27 +7,31 @@ $region Vietnam
 
 import logging
 import re
-from datetime import date
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.hls import HLSStream
+from streamlink.utils.times import localnow
+
 
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r"https?://(?:www\.)?htv\.com\.vn/truc-tuyen(?:\?channel=(?P<channel>\w+)&?|$)"
-))
+@pluginmatcher(
+    re.compile(r"https?://(?:www\.)?htv\.com\.vn/truc-tuyen(?:\?channel=(?P<channel>\w+)&?|$)"),
+)
 class HTV(Plugin):
     def get_channels(self):
-        data = self.session.http.get(self.url, schema=validate.Schema(
-            validate.parse_html(),
-            validate.xml_xpath(".//*[contains(@class,'channel-list')]//a[@data-id][@data-code]"),
-            [
-                validate.union_get("data-id", "data-code"),
-            ],
-        ))
+        data = self.session.http.get(
+            self.url,
+            schema=validate.Schema(
+                validate.parse_html(),
+                validate.xml_xpath(".//*[contains(@class,'channel-list')]//a[@data-id][@data-code]"),
+                [
+                    validate.union_get("data-id", "data-code"),
+                ],
+            ),
+        )
 
         return dict(data)
 
@@ -58,7 +62,7 @@ class HTV(Plugin):
                 "channelid": channel_id,
                 "template": "AjaxSchedules.xslt",
                 "channelcode": channel_code,
-                "date": date.today().strftime("%d-%m-%Y"),
+                "date": localnow().strftime("%d-%m-%Y"),
             },
             schema=validate.Schema(
                 validate.parse_json(),
