@@ -9,13 +9,12 @@ import hashlib
 import logging
 import re
 import sys
-from time import time
 
 from streamlink.buffers import RingBuffer
 from streamlink.plugin import Plugin, pluginargument, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.plugin.api.websocket import WebsocketClient
-from streamlink.stream.hls import HLSStream
+from streamlink.stream.hls import HLSStream, HLSStreamReader, HLSStreamWriter
 from streamlink.stream.stream import Stream, StreamIO
 from streamlink.utils.url import update_qsd
 
@@ -23,6 +22,19 @@ from streamlink.utils.url import update_qsd
 log = logging.getLogger(__name__)
 
 
+class TwitCastingHLSStreamWriter(HLSStreamWriter):
+    def should_filter_segment(self, segment):
+        return "preroll-" in segment.uri or super().should_filter_segment(segment)
+
+
+class TwitCastingHLSStreamReader(HLSStreamReader):
+    __writer__ = TwitCastingHLSStreamWriter
+
+
+class TwitCastingHLSStream(HLSStream):
+    __reader__ = TwitCastingHLSStreamReader
+
+
 @pluginmatcher(
     re.compile(r"https?://twitcasting\.tv/(?P<channel>[^/]+)"),
 )
@@ -34,22 +46,15 @@ log = logging.getLogger(__name__)
 )
 class TwitCasting(Plugin):
     _URL_API_STREAMSERVER = "https://twitcasting.tv/streamserver.php"
-    _URL_STREAM_HLS = "https://{host}/{channel}/metastream.m3u8"
-    _URL_STREAM_WEBSOCKET = "wss://{host}/ws.app/stream/{id}/fmp4/bd/1/1500?mode={mode}"
-
-    _STREAM_HOST_DEFAULT = "twitcasting.tv"
-
-    _WEBSOCKET_MODES = {
-        "main": "source",
-        "mobilesource": "mobilesource",
-        "base": None,
-    }
 
     # prefer websocket streams over HLS streams due to latency reasons
     _WEIGHTS = {
-        "main": sys.maxsize,
-        "mobilesource": sys.maxsize - 1,
-        "base": sys.maxsize - 2,
+        "ws_main": sys.maxsize,
+        "ws_mobilesource": sys.maxsize - 1,
+        "ws_base": sys.maxsize - 2,
+        "hls_high": sys.maxsize - 10,
+        "hls_medium": sys.maxsize - 11,
+        "hls_low": sys.maxsize - 12,
     }
 
     @classmethod
@@ -62,6 +67,7 @@ class TwitCasting(Plugin):
             params={
                 "target": self.match["channel"],
                 "mode": "client",
+                "player": "pc_web",
             },
             schema=validate.Schema(
                 validate.parse_json(),
@@ -70,50 +76,28 @@ class TwitCasting(Plugin):
                         "id": int,
                         "live": bool,
                     },
-                    # ignore llfmp4 websocket streams, as those seem to cause video/audio desync
-                    validate.optional("fmp4"): {
-                        "proto": str,
-                        "host": str,
-                        "source": bool,
-                        "mobilesource": bool,
+                    validate.optional("llfmp4"): {
+                        "streams": {
+                            str: validate.url(),
+                        },
                     },
-                    # ignore the "dvr" HLS URL, as it results in a 403 response
-                    validate.optional("hls"): {
-                        "host": str,
-                        "proto": str,
-                        "source": bool,
+                    validate.optional("tc-hls"): {
+                        "streams": {
+                            str: validate.url(),
+                        },
                     },
                 },
-                validate.union_get("movie", "fmp4", "hls"),
+                validate.union_get("movie", "llfmp4", "tc-hls"),
             ),
         )
 
-    def _get_streams_hls(self, data):
-        host = data.get("host") or self._STREAM_HOST_DEFAULT
-        url = self._URL_STREAM_HLS.format(host=host, channel=self.match["channel"])
-        params = {"__n": int(time() * 1000)}
+    def _get_streams_hls(self, streams, params=None):
+        for name, url in streams.items():
+            yield f"hls_{name}", TwitCastingHLSStream(self.session, url, params=params)
 
-        streams = [params]
-        if data.get("source"):
-            streams.append({"mode": "source", **params})
-
-        for params in streams:
-            yield from HLSStream.parse_variant_playlist(self.session, url, params=params).items()
-
-    def _get_streams_websocket(self, data):
-        host = data.get("host") or self._STREAM_HOST_DEFAULT
-        password = self.options.get("password")
-
-        for mode, prop in self._WEBSOCKET_MODES.items():
-            if prop is not None and not data.get(prop):
-                continue
-
-            url = self._URL_STREAM_WEBSOCKET.format(host=host, id=self.id, mode=mode)
-            if password is not None:
-                password_hash = hashlib.md5(password.encode()).hexdigest()
-                url = update_qsd(url, {"word": password_hash})
-
-            yield mode, TwitCastingStream(self.session, url)
+    def _get_streams_websocket(self, streams, params=None):
+        for name, url in streams.items():
+            yield f"ws_{name}", TwitCastingStream(self.session, url, params=params)
 
     def _get_streams(self):
         movie, websocket, hls = self._api_query_streamserver()
@@ -126,14 +110,14 @@ class TwitCasting(Plugin):
 
         self.id = movie.get("id")
 
+        params = {}
+        if password := self.options.get("password"):
+            params |= {"word": hashlib.md5(password.encode()).hexdigest()}
+
         if websocket:
-            yield from self._get_streams_websocket(websocket)
+            yield from self._get_streams_websocket(websocket["streams"], params)
         if hls:
-            try:
-                yield from self._get_streams_hls(hls)
-            except OSError:
-                if not websocket:
-                    raise
+            yield from self._get_streams_hls(hls["streams"], params)
 
 
 class TwitCastingWsClient(WebsocketClient):
@@ -189,9 +173,11 @@ class TwitCastingReader(StreamIO):
 
 
 class TwitCastingStream(Stream):
-    def __init__(self, session, url):
+    __shortname__ = "websocket"
+
+    def __init__(self, session, url, params):
         super().__init__(session)
-        self.url = url
+        self.url = update_qsd(url, params or {})
 
     def to_url(self):
         return self.url
