@@ -20,9 +20,9 @@ from streamlink.utils.crypto import AES, SHA256, pad, unpad
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(
-    r"https?://(?:www\.)?ustvnow\.com/channel/live/(?P<chname>\w+)",
-))
+@pluginmatcher(
+    re.compile(r"https?://(?:www\.)?ustvnow\.com/channel/live/(?P<chname>\w+)"),
+)
 @pluginargument(
     "username",
     required=True,
@@ -98,15 +98,18 @@ class USTVNow(Plugin):
     def get_token(self):
         if not self._token:
             log.debug("Getting new session token")
-            res = self.session.http.get(self._token_url, params={
-                "tenant_code": self.TENANT_CODE,
-                "box_id": self.box_id,
-                "product": self.TENANT_CODE,
-                "device_id": 5,
-                "display_lang_code": "ENG",
-                "device_sub_type": "",
-                "timezone": "UTC",
-            })
+            res = self.session.http.get(
+                self._token_url,
+                params={
+                    "tenant_code": self.TENANT_CODE,
+                    "box_id": self.box_id,
+                    "product": self.TENANT_CODE,
+                    "device_id": 5,
+                    "display_lang_code": "ENG",
+                    "device_sub_type": "",
+                    "timezone": "UTC",
+                },
+            )
 
             data = res.json()
             if not data["status"]:
@@ -124,10 +127,12 @@ class USTVNow(Plugin):
             "data": self.encrypt_data(json.dumps(data).encode("utf8"), key, iv).decode("utf8"),
             "metadata": self.encrypt_data(json.dumps(metadata).encode("utf8"), key, iv).decode("utf8"),
         }
-        headers = {"box-id": self.box_id,
-                   "session-id": self.get_token(),
-                   "tenant-code": self.TENANT_CODE,
-                   "content-type": "application/json"}
+        headers = {
+            "box-id": self.box_id,
+            "session-id": self.get_token(),
+            "tenant-code": self.TENANT_CODE,
+            "content-type": "application/json",
+        }
         res = self.session.http.post(self._api_url + path, data=json.dumps(post_data), headers=headers).json()
         data = {k: v and json.loads(self.decrypt_data(v, key, iv)) for k, v in res.items()}
         return data
