@@ -5,24 +5,24 @@ import logging
 import math
 import re
 from collections import defaultdict
-from collections.abc import Callable, Iterator, Sequence
 from contextlib import contextmanager
-from datetime import datetime, timedelta
+from datetime import timedelta
 from itertools import count, repeat
-from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeVar, overload
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeAlias, TypeVar, overload
 from urllib.parse import urljoin, urlparse, urlunparse
 
 from isodate import Duration, parse_datetime, parse_duration  # type: ignore[import]
 
-# noinspection PyProtectedMember
-from lxml.etree import _Attrib, _Element
-
 from streamlink.stream.dash.segment import DASHSegment, TimelineSegment
 from streamlink.utils.times import UTC, fromtimestamp, now
 
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from collections.abc import Callable, Iterator, Sequence
+    from datetime import datetime
+
+    # noinspection PyProtectedMember
+    from lxml.etree import _Attrib, _Element
 
 
 log = logging.getLogger(__name__)
@@ -365,17 +365,24 @@ class MPD(MPDNode):
 
         self.baseURLs = self.children(BaseURL)
         self.periods = self.children(Period, minimum=1)
+        self.periods_map = {period.id: period for period in self.periods if period.id is not None}
         self.programInformation = self.children(ProgramInformation)
 
     def get_representation(self, ident: TTimelineIdent) -> Representation | None:
         """
         Find the first Representation instance with a matching ident
         """
+        p, a, r = ident
         for period in self.periods:
+            if p != period.id:
+                continue
             for adaptationset in period.adaptationSets:
+                if a != adaptationset.id:
+                    continue
                 for representation in adaptationset.representations:
-                    if representation.ident == ident:
-                        return representation
+                    if r != representation.id:
+                        continue
+                    return representation
 
 
 class ProgramInformation(MPDNode):
@@ -583,6 +590,7 @@ class Representation(_RepresentationBaseType):
 
     def segments(
         self,
+        sequence: int = -1,
         init: bool = True,
         timestamp: datetime | None = None,
         **kwargs,
@@ -593,6 +601,7 @@ class Representation(_RepresentationBaseType):
         Segments appear on a timeline, for dynamic content they are only available at a certain time
         and sometimes for a limited time. For static content they are all available at the same time.
 
+        :param sequence: Sequence number
         :param init: Yield the init segment and perform other initialization logic for dynamic manifests
         :param timestamp: Optional initial timestamp for syncing timelines of multiple substreams
         :param kwargs: extra args to pass to the segment template/list
@@ -615,18 +624,17 @@ class Representation(_RepresentationBaseType):
             )
         elif segmentList:
             yield from segmentList.segments(
-                self.ident,
+                sequence=sequence,
                 init=init,
-                **kwargs,
             )
         else:
             yield DASHSegment(
+                num=sequence,
+                init=False,
+                discontinuity=False,
                 uri=self.base_url,
-                num=-1,
                 duration=self.period.duration.total_seconds() or self.root.mediaPresentationDuration.total_seconds(),
                 available_at=self.period.availabilityStartTime,
-                init=True,
-                content=True,
                 byterange=None,
             )
 
@@ -711,68 +719,55 @@ class SegmentList(_MultipleSegmentBaseType):
     # noinspection PyUnusedLocal
     def segments(
         self,
-        ident: TTimelineIdent,
+        sequence: int = -1,
         init: bool = True,
-        **kwargs,
     ) -> Iterator[DASHSegment]:
         if init and self.initialization:  # pragma: no branch
             yield DASHSegment(
-                uri=self.make_url(self.initialization.source_url),
                 num=-1,
+                init=True,
+                discontinuity=False,
+                uri=self.make_url(self.initialization.source_url),
                 duration=0.0,
                 available_at=self.period.availabilityStartTime,
-                init=True,
-                content=False,
                 byterange=self.initialization.range,
             )
-        for num, segment_url in self.segment_urls(ident, init):
+        for num, segment_url in self.segment_urls(sequence):
             yield DASHSegment(
-                uri=self.make_url(segment_url.media),
                 num=num,
+                init=False,
+                discontinuity=False,
+                uri=self.make_url(segment_url.media),
                 duration=self.duration_seconds,
                 available_at=self.period.availabilityStartTime,
-                init=False,
-                content=True,
                 byterange=segment_url.media_range,
             )
 
-    def segment_urls(self, ident: TTimelineIdent, init: bool) -> Iterator[tuple[int, SegmentURL]]:
-        if init:
+    def segment_urls(self, sequence: int) -> Iterator[tuple[int, SegmentURL]]:
+        if sequence == -1:
             if self.root.type == "static":
                 # yield all segments in a static manifest
-                start_number = self.startNumber
+                sequence = self.startNumber
                 segment_urls = self.segmentURLs
             else:
                 # yield a specific number of segments from the live-edge of dynamic manifests
-                start_number = self.calculate_optimal_start()
-                segment_urls = self.segmentURLs[start_number - self.startNumber :]
+                sequence = self.calculate_optimal_start()
+                segment_urls = self.segmentURLs[sequence - self.startNumber :]
 
         else:
             # skip segments with a lower number than the remembered segment number
             # and check if we've skipped any segments after reloading the manifest
-            start_number = self.root.timelines[ident]
-            offset = start_number - self.startNumber
+            offset = sequence - self.startNumber
 
             if offset >= 0:
                 # no segments were skipped: yield a slice of the segments
                 segment_urls = self.segmentURLs[offset:]
             else:
                 # segments were skipped: yield all segments and set the correct segment number
-                log.warning(
-                    (
-                        f"Skipped segments {start_number}-{self.startNumber - 1} after manifest reload. "
-                        if offset < -1
-                        else f"Skipped segment {start_number} after manifest reload. "
-                    )
-                    + "This is unsupported and will result in incoherent output data.",
-                )
-                start_number = self.startNumber
+                sequence = self.startNumber
                 segment_urls = self.segmentURLs
 
-        # remember the next segment number
-        self.root.timelines[ident] = start_number + len(segment_urls)
-
-        yield from enumerate(segment_urls, start_number)
+        yield from enumerate(segment_urls, sequence)
 
     def calculate_optimal_start(self) -> int:
         """Calculate the optimal segment number to start based on the suggestedPresentationDelay"""
@@ -820,22 +815,22 @@ class SegmentTemplate(_MultipleSegmentBaseType):
             init_url = self.format_initialization(base_url, **kwargs)
             if init_url:  # pragma: no branch
                 yield DASHSegment(
-                    uri=init_url,
                     num=-1,
+                    init=True,
+                    discontinuity=False,
+                    uri=init_url,
                     duration=0.0,
                     available_at=self.period.availabilityStartTime,
-                    init=True,
-                    content=False,
                     byterange=None,
                 )
         for media_url, num, duration, available_at in self.format_media(ident, base_url, timestamp=timestamp, **kwargs):
             yield DASHSegment(
-                uri=media_url,
                 num=num,
+                init=False,
+                discontinuity=False,
+                uri=media_url,
                 duration=duration,
                 available_at=available_at,
-                init=False,
-                content=True,
                 byterange=None,
             )
 
@@ -907,7 +902,7 @@ class SegmentTemplate(_MultipleSegmentBaseType):
                 ]),
             )
 
-        yield from zip(number_iter, available_iter)
+        yield from zip(number_iter, available_iter, strict=False)
 
     def segment_timeline(self, ident: TTimelineIdent) -> Iterator[tuple[int, TimelineSegment, datetime]]:
         if not self.segmentTimeline:  # pragma: no cover
