@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 import logging
+import re
 import sys
 from io import StringIO
 from pathlib import Path
 from textwrap import dedent
+from typing import TYPE_CHECKING
 from unittest.mock import Mock, call
 
 import pytest
@@ -12,12 +14,15 @@ import pytest
 import streamlink_cli.main
 import tests
 from streamlink.logger import ALL, TRACE, StringFormatter
-from streamlink.session import Streamlink
-from streamlink_cli.argparser import ArgumentParser
 from streamlink_cli.exceptions import StreamlinkCLIError
 from streamlink_cli.main import build_parser
 
 
+if TYPE_CHECKING:
+    from streamlink.session import Streamlink
+    from streamlink_cli.argparser import ArgumentParser
+
+
 @pytest.fixture(autouse=True)
 def session(session: Streamlink):
     session.plugins.load_path(Path(tests.__path__[0]) / "plugin")
@@ -662,7 +667,12 @@ class TestLogfile:
 
 
 class TestPrint:
-    @pytest.fixture(autouse=True)
+    @pytest.fixture()
+    def _color(self, request: pytest.FixtureRequest, monkeypatch: pytest.MonkeyPatch):
+        can_colorize = getattr(request, "param", False)
+        monkeypatch.setattr("_colorize.can_colorize", lambda: can_colorize)
+
+    @pytest.fixture()
     def stdout(self, monkeypatch: pytest.MonkeyPatch, capsys: pytest.CaptureFixture, session: Streamlink):
         mock_resolve_url = Mock()
         monkeypatch.setattr(session, "resolve_url", mock_resolve_url)
@@ -677,7 +687,8 @@ class TestPrint:
 
         return out
 
-    def test_usage(self, stdout: str):
+    @pytest.mark.parametrize("_color", [True, False], ids=["color", "nocolor"])
+    def test_usage(self, stdout: str, _color):
         assert (
             stdout
             == dedent("""
@@ -708,6 +719,12 @@ class TestPrint:
             in stdout
         )
 
+    @pytest.mark.python(3, 14)
+    @pytest.mark.parametrize(("argv", "_color"), [(["--help"], True)], indirect=["argv", "_color"])
+    def test_help_color(self, _color, argv: list, stdout: str):
+        # Python's _colorize module also uses ANSI escape sequences on Windows
+        assert re.match(r"\x1b\[1;\d+musage: ", stdout), "Uses color in help-text and colors its usage line"
+
     @pytest.mark.parametrize(
         ("argv", "expected"),
         [
