@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from collections.abc import Mapping
+from typing import TYPE_CHECKING
 from unittest.mock import Mock
 
 import pytest
@@ -9,6 +9,10 @@ from streamlink.stream.stream import Stream
 from streamlink_cli.main import resolve_stream_name
 
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+
 @pytest.fixture(scope="module")
 def streams():
     a = Stream(Mock())
