@@ -6,7 +6,7 @@ import re
 import time
 from contextlib import nullcontext
 from operator import eq, gt, lt
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from unittest.mock import Mock, call, patch
 
 import freezegun
@@ -33,7 +33,10 @@ from streamlink.plugin.plugin import (
     parse_params,
     stream_weight,
 )
-from streamlink.session import Streamlink
+
+
+if TYPE_CHECKING:
+    from streamlink.session import Streamlink
 
 
 class FakePlugin(Plugin):
@@ -456,9 +459,6 @@ class TestCookies:
             rfc2109=False,
         )
 
-    # TODO: py39 support end: remove explicit dummy context binding of static method
-    _create_cookie_dict = create_cookie_dict.__get__(object)
-
     @pytest.fixture()
     def pluginclass(self):
         class MyPlugin(FakePlugin):
@@ -498,8 +498,8 @@ class TestCookies:
         "plugincache",
         [
             {
-                "__cookie:test-name1:test.se:80:/": _create_cookie_dict("test-name1", "test-value1"),
-                "__cookie:test-name2:test.se:80:/": _create_cookie_dict("test-name2", "test-value2"),
+                "__cookie:test-name1:test.se:80:/": create_cookie_dict("test-name1", "test-value1"),
+                "__cookie:test-name2:test.se:80:/": create_cookie_dict("test-name2", "test-value2"),
                 "unrelated": "data",
             },
         ],
@@ -554,8 +554,8 @@ class TestCookies:
         "plugincache",
         [
             {
-                "__cookie:test-name1:test.se:80:/": _create_cookie_dict("test-name1", "test-value1", None),
-                "__cookie:test-name2:test.se:80:/": _create_cookie_dict("test-name2", "test-value2", None),
+                "__cookie:test-name1:test.se:80:/": create_cookie_dict("test-name1", "test-value1", None),
+                "__cookie:test-name2:test.se:80:/": create_cookie_dict("test-name2", "test-value2", None),
                 "unrelated": "data",
             },
         ],
@@ -573,8 +573,8 @@ class TestCookies:
         "plugincache",
         [
             {
-                "__cookie:test-name1:test.se:80:/": _create_cookie_dict("test-name1", "test-value1", None),
-                "__cookie:test-name2:test.se:80:/": _create_cookie_dict("test-name2", "test-value2", None),
+                "__cookie:test-name1:test.se:80:/": create_cookie_dict("test-name1", "test-value1", None),
+                "__cookie:test-name2:test.se:80:/": create_cookie_dict("test-name2", "test-value2", None),
                 "unrelated": "data",
             },
         ],
