@@ -1,10 +1,17 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 import pytest
 
 import tests.plugin
-from streamlink import Streamlink
 from streamlink.api import streams
 
 
+if TYPE_CHECKING:
+    from streamlink import Streamlink
+
+
 class TestStreamlinkAPI:
     @pytest.fixture(autouse=True)
     def _session(self, monkeypatch: pytest.MonkeyPatch, session: Streamlink):
