@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import threading
+from typing import TYPE_CHECKING
 from unittest.mock import Mock, call
 
 import pytest
 
-from streamlink.utils.named_pipe import NamedPipe, NamedPipeBase, NamedPipePosix, NamedPipeWindows
+from streamlink.utils.named_pipe import NamedPipe, NamedPipePosix, NamedPipeWindows
 
 
 try:
@@ -12,6 +15,10 @@ except ImportError:
     pass
 
 
+if TYPE_CHECKING:
+    from streamlink.utils.named_pipe import NamedPipeBase
+
+
 GENERIC_READ = 0x80000000
 OPEN_EXISTING = 3
 
